"""
FoodDataCentral_get_food

Get detailed food information by FDC ID from USDA FoodData Central. Returns complete nutrient pro...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def FoodDataCentral_get_food(
    fdc_id: int | str,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Get detailed food information by FDC ID from USDA FoodData Central. Returns complete nutrient pro...

    Parameters
    ----------
    fdc_id : int | str
        FoodData Central food ID (e.g., 2344723 for bananas, 2012128 for branded bana...
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "FoodDataCentral_get_food", "arguments": {"fdc_id": fdc_id}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["FoodDataCentral_get_food"]
